@@ -186,8 +186,9 @@ class OpenEuler():
 
     def get_core_src_list(self):
         core_src_list=[]
+        src_path=Path(__file__).resolve().parent / "openEuler_core_src.txt"
         try:
-            with open("openEuler_core_src.txt", "r",encoding="utf-8") as f:
+            with open(src_path, "r",encoding="utf-8") as f:
                 for line in f.readlines():
                     if not line.strip():
                         continue
